==> Task-FreecellSolver-Testing-MultiConfig-0.0.3.tar.gz: Task-FreecellSolver-Testing-MultiConfig-0.0.3/lib/Task/FreecellSolver/Testing/MultiConfig.pm <==
package Task::FreecellSolver::Testing::MultiConfig;
$Task::FreecellSolver::Testing::MultiConfig::VERSION = '0.0.3';
use warnings;
use strict;

use 5.012;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::FreecellSolver::Testing::MultiConfig - install the CPAN dependencies of
the Freecell Solver multi-config test suite.

=head1 VERSION

version 0.0.3

=head1 TASK CONTENTS

=head2 Freecell Solver deps

=head3 L<App::Deps::Verify>

=head3 L<App::Docmake>

=head3 L<Code::TidyAll::Plugin::ClangFormat>

=head3 L<Code::TidyAll::Plugin::ESLint>

=head3 L<Code::TidyAll::Plugin::TSLint>

=head3 L<Dist::Zilla::Plugin::Test::Kwalitee>

=head3 L<Dist::Zilla::Plugin::Test::TidyAll>

=head3 L<Dist::Zilla::PluginBundle::SHLOMIF>

=head3 L<HTML::Spelling::Site::Whitelist>

=head3 L<Perl::Critic::Freenode>

=head3 L<Pod::Weaver::PluginBundle::SHLOMIF>

=head3 L<Pod::Weaver::Section::Support>

=head3 L<Task::FreecellSolver::Testing>

=head3 L<Test::HTML::Recursive::DeprecatedTags>

=head3 L<Test::Perl::Critic::Policy>

=head3 L<Test::Pod::Coverage>

=head1 AUTHOR

Shlomi Fish, L<http://www.shlomifish.org/>

=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/Task-FreecellSolver-Testing-MultiConfig>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=Task-FreecellSolver-Testing-MultiConfig>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/Task-FreecellSolver-Testing-MultiConfig>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/T/Task-FreecellSolver-Testing-MultiConfig>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=Task-FreecellSolver-Testing-MultiConfig>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=Task::FreecellSolver::Testing::MultiConfig>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-task-freecellsolver-testing-multiconfig at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Task-FreecellSolver-Testing-MultiConfig>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/fc-solve>

  git clone git://github.com/shlomif/fc-solve.git

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/fc-solve/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=cut

==> Task-FreecellSolver-Testing-MultiConfig-0.0.4.tar.gz: Task-FreecellSolver-Testing-MultiConfig-0.0.4/lib/Task/FreecellSolver/Testing/MultiConfig.pm <==
package Task::FreecellSolver::Testing::MultiConfig;
$Task::FreecellSolver::Testing::MultiConfig::VERSION = '0.0.4';
use warnings;
use strict;

use 5.012;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::FreecellSolver::Testing::MultiConfig - install the CPAN dependencies of
the Freecell Solver multi-config test suite.

=head1 VERSION

version 0.0.4

=head1 TASK CONTENTS

=head2 Freecell Solver deps

=head3 L<App::Deps::Verify>

=head3 L<App::Docmake>

=head3 L<Code::TidyAll::Plugin::ClangFormat>

=head3 L<Code::TidyAll::Plugin::ESLint>

=head3 L<Code::TidyAll::Plugin::TSLint>

=head3 L<Dist::Zilla::Plugin::Test::Kwalitee>

=head3 L<Dist::Zilla::Plugin::Test::TidyAll>

=head3 L<Dist::Zilla::PluginBundle::SHLOMIF>

=head3 L<HTML::Spelling::Site::Whitelist>

=head3 L<HTML::Toc>

=head3 L<HTML::TocGenerator>

=head3 L<Markdent>

=head3 L<Parallel::ForkManager::Segmented>

=head3 L<Perl::Critic::Freenode>

=head3 L<Pod::Weaver::PluginBundle::SHLOMIF>

=head3 L<Pod::Weaver::Section::Support>

=head3 L<Task::FreecellSolver::Testing>

=head3 L<Test::File::Find::CaseCollide>

=head3 L<Test::HTML::Recursive::DeprecatedTags>

=head3 L<Test::Perl::Critic::Policy>

=head3 L<Test::Pod::Coverage>

=head3 L<Text::WrapAsUtf8>

=head1 AUTHOR

Shlomi Fish, L<http://www.shlomifish.org/>

=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/Task-FreecellSolver-Testing-MultiConfig>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=Task-FreecellSolver-Testing-MultiConfig>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/Task-FreecellSolver-Testing-MultiConfig>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/T/Task-FreecellSolver-Testing-MultiConfig>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=Task-FreecellSolver-Testing-MultiConfig>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=Task::FreecellSolver::Testing::MultiConfig>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-task-freecellsolver-testing-multiconfig at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Task-FreecellSolver-Testing-MultiConfig>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/fc-solve>

  git clone git://github.com/shlomif/fc-solve.git

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/fc-solve/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=cut
